pub enum ModuleCommand {
Show 13 variants
Browse {
name: ModuleName,
},
Config {
command: Option<ConfigCommand>,
name: Option<ModuleName>,
},
Disable {
names: Vec<ModuleName>,
},
Doc {
name: ModuleName,
},
Enable {
names: Vec<ModuleName>,
},
Inspect {
name: ModuleName,
output: Option<String>,
},
Install {
names: Vec<ModuleName>,
version: Option<String>,
model_size: Option<String>,
},
Link {
name: ModuleName,
},
List {
output: Option<String>,
},
Resolve {
url: String,
},
Search {
query: Vec<String>,
output: Option<String>,
},
Uninstall {
names: Vec<ModuleName>,
},
Upgrade {
names: Vec<ModuleName>,
version: Option<String>,
model_size: Option<String>,
},
}Variants
Browse
Open the module’s package page in a web browser
Fields
name: ModuleNameThe name of the module to browse
Config
Show or change an installed module’s configuration
Fields
command: Option<ConfigCommand>name: Option<ModuleName>The name of the module whose configuration to show
Disable
Disable modules
Fields
names: Vec<ModuleName>The names of the modules to disable
Doc
Print an installed module’s documentation
Fields
name: ModuleNameThe name of the module whose documentation to print
Enable
Enable modules
Fields
names: Vec<ModuleName>The names of the modules to enable
Inspect
Inspect a module’s manifest, state, and configuration status
Fields
name: ModuleNameThe name of the module to inspect
Install
Install an available module locally
Fields
names: Vec<ModuleName>The names of the modules to install
Link
Print the module’s package link
Fields
name: ModuleNameThe name of the module to link to
List
List installed modules
Resolve
Resolve a given URL to modules which can handle it
Search
Search the index of available modules
Fields
Uninstall
Uninstall a currently installed module
Fields
names: Vec<ModuleName>The names of the modules to uninstall
Upgrade
Upgrade currently installed modules
By default upgrades all installed modules.
Implementations
Sourceimpl ModuleCommand
impl ModuleCommand