pub enum ProxyCommand {
Serve {
args: ProxyServeArgs,
},
Url {},
Host {},
Port {},
Config {
app: ProxyConfigTarget,
format: Option<String>,
},
Install {
apps: Vec<ProxyInstallTarget>,
},
}Variants
Serve
Run an OpenAI-compatible endpoint at http://127.0.0.1:1920.
Requests are proxied to enabled providers (currently always OpenRouter).
Reads OPENROUTER_API_KEY for the OpenRouter API key (required).
Reads ASIMOV_PROXY_PORT for the port to bind to (default: 1920).
Reads ASIMOV_PROXY_BIND for the address to bind to (default: 127.0.0.1).
Reads ASIMOV_PROXY_LOG_FILE for a file to append request and response bodies to (optional).
Honors the conventional https_proxy/HTTPS_PROXY, all_proxy/ALL_PROXY, and no_proxy/NO_PROXY environment variables for reaching upstream through an HTTP(S) or SOCKS5 proxy.
Fields
args: ProxyServeArgsUrl
Print the proxy URL.
Host
Print the proxy host.
Port
Print the proxy port.
Config
Show configuration for using the proxy endpoint.
Fields
app: ProxyConfigTargetThe target application to configure.
Install
Configure applications to use the proxy endpoint.
Fields
apps: Vec<ProxyInstallTarget>The target applications to configure.
Implementations
Sourceimpl ProxyCommand
impl ProxyCommand