pub struct ExternalResult {
pub code: SysexitsError,
pub stdout: Option<Vec<u8>>,
pub stderr: Option<Vec<u8>>,
}Fields
code: SysexitsErrorReturn code of the executed command.
stdout: Option<Vec<u8>>If pipe_output is true, this field contains stdout, otherwise its None.
stderr: Option<Vec<u8>>If pipe_output is true, this field contains stderr, otherwise its None.